import Vue from 'vue'
import Router from 'vue-router'
// import menuNoShowData from './menu.js'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const moreRoutes = [
  {
    path: '/base',
    component: Layout,
    redirect: '/base/dict',
    name: 'Base',
    alwaysShow: true,
    meta: { title: '基础数据', icon: 'dashboard' },
    children: [
      {
        path: 'dict',
        name: 'Dict',
        component: () => import('@/views/base/dict'),
        meta: { title: '系统字典' }
      },
      {
        path: 'dictDtl',
        name: 'DictDtl',
        hidden: true,
        component: () => import('@/views/base/dictDtl'),
        meta: { title: '系统字典详情' }
      }
    ]
  },
  {
    path: '/news',
    component: Layout,
    redirect: '/news/index',
    children: [{
      path: 'index',
      name: 'NewsIndex',
      component: () => import('@/views/news/index'),
      meta: { title: '洪楼News', icon: 'dashboard' }
    }]
  },
  {
    path: '/house',
    component: Layout,
    redirect: '/house/index',
    name: 'House',
    meta: { title: '楼盘管理', icon: 'dashboard' },
    children: [
      {
        path: 'index',
        name: 'HouseIndex',
        component: () => import('@/views/house/index'),
        meta: { title: '楼盘列表' }
      },
      {
        path: 'news',
        name: 'HouseNews',
        hidden: true,
        component: () => import('@/views/house/news'),
        meta: { title: '楼盘动态' }
      },
      {
        path: 'theme',
        name: 'HouseTheme',
        component: () => import('@/views/house/theme'),
        meta: { title: '模板主题' }
      },
      {
        path: 'comment',
        name: 'HouseComment',
        component: () => import('@/views/house/comment'),
        meta: { title: '楼盘评论' }
      },
      {
        path: 'old',
        name: 'HouseOld',
        component: () => import('@/views/house/old'),
        meta: { title: '二手房管理' }
      },
    ]
  },
  {
    path: '/school',
    component: Layout,
    redirect: '/school/index',
    children: [{
      path: 'index',
      name: 'SchoolIndex',
      component: () => import('@/views/school/index'),
      meta: { title: '学校管理', icon: 'dashboard' }
    }]
  },
  // {
  //   path: '/user',
  //   component: Layout,
  //   redirect: '/user/index',
  //   children: [{
  //     path: 'index',
  //     name: 'UserIndex',
  //     component: () => import('@/views/user/index'),
  //     meta: { title: '用户管理', icon: 'dashboard', affix: true }
  //   }]
  // },
  {
    path: '/qa',
    component: Layout,
    redirect: '/qa/index',
    children: [{
      path: 'index',
      name: 'QaIndex',
      component: () => import('@/views/qa/index'),
      meta: { title: '问答管理', icon: 'dashboard' }
    }]
  },
  {
    path: '/tupai',
    component: Layout,
    redirect: '/tupai/index',
    children: [{
      path: 'index',
      name: 'TupaiIndex',
      component: () => import('@/views/tupai/index'),
      meta: { title: '土拍管理', icon: 'dashboard' }
    }]
  },
]
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '首页', icon: 'dashboard' }
    }]
  },
  ...moreRoutes
]


/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  // {
  //   path: '/example',
  //   component: Layout,
  //   redirect: '/example/table',
  //   name: 'Example',
  //   meta: { title: '测试', icon: 'dashboard' },
  //   children: [
  //     {
  //       path: 'table',
  //       name: 'Table',
  //       component: () => import('@/views/table/index'),
  //       meta: { title: 'Table' }
  //     },
  //     {
  //       path: 'tree',
  //       name: 'Tree',
  //       component: () => import('@/views/tree/index'),
  //       meta: { title: 'Tree' }
  //     }
  //   ]
  // },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
